glob

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package glob provides glob pattern matching with ** support and brace expansion. It is used to match file paths against VS Code-style glob patterns (e.g. applyTo).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Match

func Match(pattern, name string) bool

Match reports whether name matches the shell glob pattern. Unlike path.Match, it supports ** as a wildcard spanning multiple path segments and {a,b} brace expansion (e.g. "**/*.{go,ts}"). name and pattern should use forward slashes.

func MatchAny

func MatchAny(patterns []string, name string) bool

MatchAny reports whether name matches any of the patterns.

Types

This section is empty.

Jump to