Documentation
¶
Overview ¶
Package syncer provides a reusable background sync goroutine. It runs a sync function immediately on start, then periodically.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Syncer ¶
type Syncer struct {
// contains filtered or unexported fields
}
Syncer runs a function on a periodic interval in the background.
func (*Syncer) ForceSync ¶
func (s *Syncer) ForceSync()
ForceSync runs the sync function immediately (blocks until complete).
Click to show internal directories.
Click to hide internal directories.